summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorJouni Koivuviita <jouni.koivuviita@itmill.com>2009-09-03 12:04:31 +0000
committerJouni Koivuviita <jouni.koivuviita@itmill.com>2009-09-03 12:04:31 +0000
commit1e12ab5624d4b7831c44b055b4b37041a04bdd52 (patch)
tree98caec9e185bf71701114c2f657b53b23dce2aef /src
parent85ff099f917fe62051ae99819884da5303775146 (diff)
downloadvaadin-framework-1e12ab5624d4b7831c44b055b4b37041a04bdd52.tar.gz
vaadin-framework-1e12ab5624d4b7831c44b055b4b37041a04bdd52.zip
Fixed some typos in Sampler features and edited the CssLayout example styles, now more "Vaadiness" included.
svn changeset:8653/svn branch:6.1
Diffstat (limited to 'src')
-rw-r--r--src/com/vaadin/demo/sampler/features/layouts/CssLayouts.java21
-rw-r--r--src/com/vaadin/demo/sampler/features/layouts/CssLayoutsExample.java7
-rw-r--r--src/com/vaadin/demo/sampler/features/layouts/LayoutAlignment.java2
-rw-r--r--src/com/vaadin/demo/sampler/features/layouts/LayoutSpacing.java2
4 files changed, 15 insertions, 17 deletions
diff --git a/src/com/vaadin/demo/sampler/features/layouts/CssLayouts.java b/src/com/vaadin/demo/sampler/features/layouts/CssLayouts.java
index 65ba2dab33..d7a7165752 100644
--- a/src/com/vaadin/demo/sampler/features/layouts/CssLayouts.java
+++ b/src/com/vaadin/demo/sampler/features/layouts/CssLayouts.java
@@ -16,18 +16,17 @@ public class CssLayouts extends Feature {
@Override
public String getDescription() {
- // TODO
- return "Most commonly developers usign Vaadin don't want to think "
+ return "Most commonly developers using Vaadin don't want to think "
+ "of the browser environment at all. With the flexible "
- + "layout API found from grid, horizontal and vertical "
- + "layout developers can build almost anything with plain "
- + "Java. But sometimes experienced web developers miss "
- + "flexibility of CSS and HTML. CssLayout is a simple "
- + "layout that puts contained componets into div element. "
- + "It has a simple DOM structure and it leaves all the power "
- + "to CSS designer hands. Having a very narrow feature set"
- + ", CssLayout is also the fastest layout to render in "
- + "Vaadin.";
+ + "layout API found from Grid, Horizontal and Vertical "
+ + "layouts, developers can build almost anything with plain "
+ + "Java. But sometimes experienced web developers miss the "
+ + "flexibility that pure CSS and HTML can offer.<br /><br />"
+ + "CssLayout is a simple layout that places its contained "
+ + "components into a <code>DIV</code> element. It has a "
+ + "simple DOM structure and it leaves all the power to the "
+ + "CSS designer's hands. While having a very narrow feature "
+ + "set, CssLayout is the fastest layout to render in Vaadin.";
}
@Override
diff --git a/src/com/vaadin/demo/sampler/features/layouts/LayoutAlignment.java b/src/com/vaadin/demo/sampler/features/layouts/LayoutAlignment.java
index 2c28c887ea..337134f457 100644
--- a/src/com/vaadin/demo/sampler/features/layouts/LayoutAlignment.java
+++ b/src/com/vaadin/demo/sampler/features/layouts/LayoutAlignment.java
@@ -12,7 +12,7 @@ public class LayoutAlignment extends Feature {
@Override
public String getName() {
- return "Component Alignment";
+ return "Component alignment";
}
@Override
diff --git a/src/com/vaadin/demo/sampler/features/layouts/LayoutSpacing.java b/src/com/vaadin/demo/sampler/features/layouts/LayoutSpacing.java
index 422a861add..ced7dde671 100644
--- a/src/com/vaadin/demo/sampler/features/layouts/LayoutSpacing.java
+++ b/src/com/vaadin/demo/sampler/features/layouts/LayoutSpacing.java
@@ -12,7 +12,7 @@ public class LayoutSpacing extends Feature {
@Override
public String getName() {
- return "Layout Spacing";
+ return "Layout spacing";
}
@Override
diff --git a/src/com/vaadin/demo/sampler/features/layouts/CssLayoutsExample.java b/src/com/vaadin/demo/sampler/features/layouts/CssLayoutsExample.java
index 1e1bffbedc..1184357ab5 100644
--- a/src/com/vaadin/demo/sampler/features/layouts/CssLayoutsExample.java
+++ b/src/com/vaadin/demo/sampler/features/layouts/CssLayoutsExample.java
@@ -34,7 +34,6 @@ public class CssLayoutsExample extends VerticalLayout {
+ "of the layout (and centered unless I'm in IE6)");
bottomCenter.setSizeUndefined(); // disable 100% default width
bottomCenter.setStyleName("footer");
- // bottomCenter.setWidth("50px");
CssLayout cssLayout = new CssLayout() {
int brickCounter = 0;
@@ -45,8 +44,8 @@ public class CssLayoutsExample extends VerticalLayout {
if (c instanceof Brick) {
brickCounter++;
if (brickCounter % 3 == 0) {
- // make every third brick colored and bold
- return "color: #ff6611; font-weight:bold;";
+ // make every third brick colored and italic
+ return "color: #ff6611; font-style: italic;";
}
}
return null;
@@ -71,7 +70,7 @@ public class CssLayoutsExample extends VerticalLayout {
static class Brick extends Label {
public Brick() {
super("Brick");
- // disable 100% that label has by default
+ // disable 100% width that label has by default
setSizeUndefined();
setStyleName("brick");
}